@@ -2,10 +2,8 @@ use strict;
 use warnings;
 
 package Template::AutoFilter;
-BEGIN {
-  $Template::AutoFilter::VERSION = '0.111980';
-}
 
+our $VERSION = '0.112070'; # VERSION
 # ABSTRACT: Template::Toolkit with automatic filtering
 
 
@@ -36,7 +34,7 @@ Template::AutoFilter - Template::Toolkit with automatic filtering
 
 =head1 VERSION
 
-version 0.111980
+version 0.112070
 
 =head1 SYNOPSIS
 
@@ -91,6 +89,25 @@ pass-through filter and creates the AutoFilter Parser.
 All parameters passed to this new() will also be passed to the parser's
 new().
 
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
+
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-template-autofilter at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Template-AutoFilter>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
+
+L<https://github.com/wchristian/Template-AutoFilter>
+
+  git clone https://github.com/wchristian/Template-AutoFilter
+
 =head1 AUTHOR
 
 Christian Walde <walde.christian@googlemail.com>
